Description Details Author(s) Source
The package FORA includes a set of functions to visualize forecast features and for making significant conclusion about difference between results obtained by user-defined forecasting models.The comparison performed according build-in error measures, such as common-used as well as advanced and stable measures
| Package: | FORA |
| Type: | Package |
| License: | GPL3 |
Andrey Davydenko, Maxim Shcherbakov and Sai Van Cuong Maintainer: Sai Van Cuong "svcuonghvktqs@gmail.com"
https://github.com/svcuonghvktqs/FORA.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.