boxplotPEs: Boxplot of percentage errors for the given data from dataset

Description Usage Arguments Value Author(s) References See Also Examples

Description

This function returns box and whisker plots of percentage errors for the given data from dataset for different methods

Usage

1
2
boxplotPEs(df, useLogs = FALSE, notch = FALSE, limits = NULL,
  showOutliers = NULL, ...)

Arguments

df

A data frame containing columns "actual" and "forecast" and "method".

useLogs

logical. If useLogs==TRUE the resulting box and whisker plotted in logarithmic scales. If FALSE the resulting box and whisker plotted in scales by default.

notch

logical. If the notch==TRUE, a notch is drawn in each side of the boxes.

limits

The minimum and maximum values on the axis APE. If xlim is NULL, minimum and maximum values are calculated based on given data.

showOutliers

If showOutliers is NA, the outliers are not drawn.

...

Other undocumented arguments.

Value

boxplotPEs function returns box and whisker plot of percentage errors for the given data from dataset containing columns named "actual", "forecast" and "method" for different methods.

Author(s)

Andrey Davydenko, Maxim Shcherbakov and Sai Van Cuong

References

Rob J. Hyndman, Anne B. Koehler (2006) Volume title: "International Journal of Forecasting".Chapter title: Another look at measures of forecast accuracy. Chapter pages : (p.679-688).http://eva.fcea.edu.uy/pluginfile.php/109034/mod_resource/content/0/2006_Hyndman_Predicc.pdf.

See Also

boxplotAPEs, plotPRD.

Examples

1
2
3
4
boxplotPEs(FORAYearForecast)
data1 <- FORAYearForecast[1:300,]
boxplotPEs(data1)
boxplotPEs(FORAYearForecast, notch = TRUE, limits = c(0, 0.5), showOutlier = NA)

svcuonghvktqs/FORA documentation built on May 20, 2019, 9:57 a.m.