Description Usage Arguments Value Author(s) References See Also Examples
This function calculates and returns list of two dataframes, where the first data frame contains MASEs for the given data, diferent horizons and methods, the second one contains ranked list of the methods according to MASEs. Also the function plots MASEs for different hirizons and methods.
1 | calculateMASEs(frame, frame2, sort = FALSE)
|
frame |
A data frame containing columns "seies_id, actual", "forecast", "method", and "horizon". |
frame2 |
A data frame containing observations of each time series (containing columns named "series_id" and "value"). |
sort |
logical. If TRUE the resulting list of MASEs dataframe and ranked dataframe of MASEs sorting by average value. |
calculateMASEs function calculates and returns list of two dataframes,
where the first data frame contains MASEs for the given data, diferent horizons and methods,
the second one contains ranked dataframe of the methods according to MASEs.
Also the function plots MASEs for different hirizons and methods.
Sai Van Cuong, Maixm Shcherbakov and Andrey Davydenko
Andrey Davydenko, Robert Fildes (2015) Volume title: Forecast Error Measures: Critical Review and Practical Recommendations. https://www.researchgate.net/publication/284947381_Forecast_Error_Measures_Critical_Review_and_Practical_Recommendations.
Chao Chen, Jamie Twycross, Jonathan M. Garibaldi (2017) Volume title: A new accuracy measure based on bounded relative error for time series forecasting. http://journals.plos.org/plosone/article?id=10.1371/journal.pone.0174202.
MV Shcherbakov, A Brebels, NL Shcherbakova (2013) Volume title: Information Technologies in Modern Industry, Education & Society. https://www.researchgate.net/publication/281718517_A_survey_of_forecast_error_measures. http://eva.fcea.edu.uy/pluginfile.php/109034/mod_resource/content/0/2006_Hyndman_Predicc.pdf.
calculateAvgRelMAEs, calculateGMAPEs, calculateGMRAEs, calculateMAD_MEAN_ratio,
calculateMAEs, calculateMAPEs, calculateMdAPEs, calculateMPEs, calculateMSEs,
calculatePB_MAEs, calculateRMSEs, calculateSMAPEs, calculateSMdAPEs.
1 2 | calculateMASEs(frame = FORAYearForecast, frame2 = FORAYearSeries)
calculateMASEs(frame = FORAYearForecast, frame2 = FORAYearSeries, sort = TRUE)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.