calculateSMdAPEs: Symmetric Median Absolute Percentage Errors(SMdAPEs)

Description Usage Arguments Value Author(s) References See Also Examples

Description

This function calculates and returns list of two dataframes, where the first data frame contains SMdAPEs for the given data, diferent horizons and methods, the second one contains ranked list of the methods according to SMdAPEs. Also the function plots SMdAPEs for different hirizons and methods.

Usage

1

Arguments

frame

A data frame containing columns "actual", "forecast", "method", and "horizon".

sort

logical. If TRUE the resulting list of SMdAPEs dataframe and ranked dataframe of SMdAPEs sorting by average value.

Value

calculateSMdAPEs function calculates and returns list of two dataframes, where the first data frame contains SMdAPEs for the given data, diferent horizons and methods, the second one contains ranked dataframe of the methods according to SMdAPEs. Also the function plots SMdAPEs for different hirizons and methods.

Author(s)

Sai Van Cuong, Maixm Shcherbakov and Andrey Davydenko

References

Rob J. Hyndman, Anne B. Koehler (2006) Volume title: "International Journal of Forecasting". Chapter title: Another look at measures of forecast accuracy. Chapter pages : (p.679-688). http://eva.fcea.edu.uy/pluginfile.php/109034/mod_resource/content/0/2006_Hyndman_Predicc.pdf.

See Also

calculateAvgRelMAEs, calculateGMAPEs, calculateGMRAEs, calculateMAD_MEAN_ratio, calculateMAEs, calculateMAPEs, calculateMASEs, calculateMdAPEs, calculateMPEs, calculateMSEs, calculatePB_MAEs, calculateRMSEs, calculateSMAPEs.

Examples

1
2
3
4
5
6

svcuonghvktqs/FORA documentation built on May 20, 2019, 9:57 a.m.