Description Usage Arguments Value Author(s) References See Also Examples
This function calculates and returns list of two dataframes, where the first data frame contains SMdAPEs for the given data, diferent horizons and methods, the second one contains ranked list of the methods according to SMdAPEs. Also the function plots SMdAPEs for different hirizons and methods.
1 |
frame |
A data frame containing columns "actual", "forecast", "method", and "horizon". |
sort |
logical. If TRUE the resulting list of SMdAPEs dataframe and ranked dataframe of SMdAPEs sorting by average value. |
calculateSMdAPEs function calculates and returns list of two dataframes,
where the first data frame contains SMdAPEs for the given data, diferent horizons and methods,
the second one contains ranked dataframe of the methods according to SMdAPEs.
Also the function plots SMdAPEs for different hirizons and methods.
Sai Van Cuong, Maixm Shcherbakov and Andrey Davydenko
Rob J. Hyndman, Anne B. Koehler (2006) Volume title: "International Journal of Forecasting". Chapter title: Another look at measures of forecast accuracy. Chapter pages : (p.679-688). http://eva.fcea.edu.uy/pluginfile.php/109034/mod_resource/content/0/2006_Hyndman_Predicc.pdf.
calculateAvgRelMAEs, calculateGMAPEs, calculateGMRAEs, calculateMAD_MEAN_ratio,
calculateMAEs, calculateMAPEs, calculateMASEs,
calculateMdAPEs, calculateMPEs, calculateMSEs, calculatePB_MAEs,
calculateRMSEs, calculateSMAPEs.
1 2 3 4 5 6 | calculateSMdAPEs(frame = FORAYearForecast)
calculateSMdAPEs(frame = FORAYearForecast, sort = TRUE)
data1 <- subset(FORAYearForecast, actual >= 5000| forecast < 8000)
data2 <- FORAYearForecast[1:300,]
calculateSMdAPEs(frame = data1, sort = TRUE)
calculateSMdAPEs(frame = data2, sort = TRUE)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.